#! /bin/sh
#********************************************
#*                                          * 
#*   LICENSED MATERIALS - PROPERTY OF IBM   *   
#*   "RESTRICTED MATERIALS OF IBM"          *           
#*   5724-M00                               *                
#*   (C) COPYRIGHT IBM CORP. 2005           *     
#*                                          *          
#********************************************
#
# Usage: db2_create_automgr_db_inst.sh <db_name> <instance_owner> <instance_pwd> <drop_sql> <create_sql>
#
# Parameters:
#  <db_name>         - The database is created with this name.
#  <instance_owner>  - The instance owner.
#  <instance_pwd>    - The password for instance owner.
#  <drop_sql>        - SQL script dropping tables in the specified database.
#  <create_sql>      - SQL script creating tables in the specified database.
#
# Description of exit codes:
# 0 - Script completed successfully
# 1 - Failed to execute db2start
# 2 - Failed to create the database
# 3 - Failed to connect to the database
# 4 - Failed to execute SQL Statements
#

DB_NAME=$1
INSTANCE_OWNER=$2
INSTANCE_PWD=$3
DROP_SQL=$4
CREATE_SQL=$5

# Some of the following commands are allowed to return a SQL statement error
# (Return Code 4). This is the reason, why 'test' is called with the option
# '-gt 4'.

# Returns 4, if the DB Manager is already started.
db2 -v db2start
if [ $? -gt 4 ]; then
	exit 1
fi


# Ignore DROP DATABASE problems
db2 -v DROP DATABASE $DB_NAME


db2 -v CREATE DATABASE $DB_NAME USING CODESET UTF-8 TERRITORY us
if [ $? -gt 0 ]; then
	exit 2
fi	

db2 -v CONNECT TO $DB_NAME USER $INSTANCE_OWNER USING $INSTANCE_PWD
if [ $? -ne 0 ]; then
	exit 3
fi

# Every error that occurs during drop can be ignored.
db2 -tvf $DROP_SQL

db2 -tvf $CREATE_SQL
if [ $? -ne 0 ]; then
	exit 4
fi

exit 0
